
Keras Transformer
=================


.. image:: https://travis-ci.org/CyberZHG/keras-transformer.svg
   :target: https://travis-ci.org/CyberZHG/keras-transformer
   :alt: Travis


.. image:: https://coveralls.io/repos/github/CyberZHG/keras-transformer/badge.svg?branch=master
   :target: https://coveralls.io/github/CyberZHG/keras-transformer
   :alt: Coverage


Install
-------

.. code-block:: bash

   pip install keras-transformer
